==> apache-superset-3.0.1-source.tar.gz: apache-superset-3.0.1rc2/superset-frontend/packages/superset-ui-demo/storybook/stories/plugins/plugin-chart-echarts/Pie/data.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export const weekday = [
  { Day: 'Friday', 'SUM(AIR_TIME)': 1943661 },
  { Day: 'Saturday', 'SUM(AIR_TIME)': 1798845 },
  { Day: 'Thursday', 'SUM(AIR_TIME)': 1626157 },
  { Day: 'Sunday', 'SUM(AIR_TIME)': 1048653 },
];

export const population = [
  { Country: 'China', Population: 58345455000 },
  { Country: 'India', Population: 46023037597 },
  { Country: 'United States', Population: 13604468357 },
  { Country: 'Indonesia', Population: 9357861231 },
  { Country: 'Brazil', Population: 7752058955 },
  { Country: 'Russian Federation', Population: 7667188460 },
  { Country: 'Japan', Population: 6454620759 },
  { Country: 'Pakistan', Population: 5696041480 },
  { Country: 'Bangladesh', Population: 5549261462 },
  { Country: 'Nigeria', Population: 5259800493 },
  { Country: 'Mexico', Population: 4444653964 },
  { Country: 'Germany', Population: 4361793335 },
  { Country: 'Vietnam', Population: 3420037000 },
  { Country: 'Philippines', Population: 3272015554 },
  { Country: 'United Kingdom', Population: 3169118137 },
  { Country: 'France', Population: 3151638853 },
  { Country: 'Italy', Population: 3082869665 },
  { Country: 'Egypt, Arab Rep.', Population: 2967887581 },
  { Country: 'Thailand', Population: 2827157965 },
  { Country: 'Turkey', Population: 2805220683 },
  { Country: 'Ethiopia', Population: 2750952916 },
  { Country: 'Iran, Islamic Rep.', Population: 2717528355 },
  { Country: 'Ukraine', Population: 2657782543 },
  { Country: 'Korea, Rep.', Population: 2216456927 },
  { Country: 'Myanmar', Population: 2126848982 },
  { Country: 'Spain', Population: 2115316751 },
  { Country: 'Congo, Dem. Rep.', Population: 2015439254 },
  { Country: 'Poland', Population: 1976772515 },
  { Country: 'South Africa', Population: 1871083248 },
  { Country: 'Colombia', Population: 1776189608 },
  { Country: 'Argentina', Population: 1728332290 },
  { Country: 'Canada', Population: 1470276931 },
  { Country: 'Tanzania', Population: 1413734053 },
  { Country: 'Algeria', Population: 1317290647 },
  { Country: 'Morocco', Population: 1277441301 },
  { Country: 'Kenya', Population: 1253201109 },
  { Country: 'Romania', Population: 1171333228 },
  { Country: 'Peru', Population: 1121937313 },
  { Country: 'Sudan', Population: 1118903636 },
  { Country: 'Uzbekistan', Population: 1053380227 },
  { Country: 'Korea, Dem. Rep.', Population: 1047335229 },
  { Country: 'Venezuela, RB', Population: 1036057583 },
  { Country: 'Nepal', Population: 1007162709 },
  { Country: 'Uganda', Population: 987376102 },
  { Country: 'Iraq', Population: 983604177 },
  { Country: 'Malaysia', Population: 978122682 },
  { Country: 'Australia', Population: 903260509 },
  { Country: 'Afghanistan', Population: 887557752 },
  { Country: 'Sri Lanka', Population: 881137000 },
  { Country: 'Saudi Arabia', Population: 828451525 },
  { Country: 'Mozambique', Population: 807229371 },
  { Country: 'Netherlands', Population: 803013980 },
  { Country: 'Ghana', Population: 801844889 },
  { Country: 'Kazakhstan', Population: 797168043 },
  { Country: 'Chile', Population: 696739897 },
  { Country: 'Yemen, Rep.', Population: 695646128 },
  { Country: 'Cameroon', Population: 664127790 },
  { Country: 'Syrian Arab Republic', Population: 663924524 },
  { Country: 'Madagascar', Population: 656478313 },
  { Country: 'Angola', Population: 641906296 },
  { Country: "Cote d'Ivoire", Population: 634194484 },
  { Country: 'Hungary', Population: 566995908 },
  { Country: 'Czech Republic', Population: 559416359 },
  { Country: 'Belgium', Population: 551921585 },
  { Country: 'Cuba', Population: 550461345 },
  { Country: 'Greece', Population: 547065293 },
  { Country: 'Ecuador', Population: 537148542 },
  { Country: 'Portugal', Population: 536945679 },
  { Country: 'Belarus', Population: 524490000 },
  { Country: 'Cambodia', Population: 523555378 },
  { Country: 'Zimbabwe', Population: 509866860 },
  { Country: 'Burkina Faso', Population: 505122912 },
  { Country: 'Mali', Population: 500758830 },
  { Country: 'Guatemala', Population: 498361800 },
  { Country: 'Niger', Population: 471910464 },
  { Country: 'Malawi', Population: 470725354 },
  { Country: 'Sweden', Population: 468210684 },
  { Country: 'Bulgaria', Population: 456247765 },
  { Country: 'Zambia', Population: 438847085 },
  { Country: 'Austria', Population: 426785647 },
  { Country: 'Tunisia', Population: 415992799 },
  { Country: 'Senegal', Population: 414475224 },
  { Country: 'Haiti', Population: 377521290 },
  { Country: 'Azerbaijan', Population: 374210660 },
  { Country: 'Dominican Republic', Population: 373939753 },
  { Country: 'Switzerland', Population: 369360744 },
  { Country: 'Bolivia', Population: 368308373 },
  { Country: 'Guinea', Population: 362469063 },
  { Country: 'Chad', Population: 355875809 },
  { Country: 'Rwanda', Population: 347121852 },
  { Country: 'Somalia', Population: 332677926 },
  { Country: 'South Sudan', Population: 319024522 },
  { Country: 'Burundi', Population: 305731834 },
  { Country: 'Hong Kong SAR, China', Population: 298353905 },
  { Country: 'Benin', Population: 290736360 },
  { Country: 'Denmark', Population: 283435789 },
  { Country: 'Slovak Republic', Population: 276228375 },
  { Country: 'Finland', Population: 271585488 },
  { Country: 'Tajikistan', Population: 267603756 },
  { Country: 'El Salvador', Population: 266413287 },
  { Country: 'Israel', Population: 263866720 },
  { Country: 'Honduras', Population: 257791863 },
  { Country: 'Croatia', Population: 246197511 },
  { Country: 'Georgia', Population: 241070850 },
  { Country: 'Norway', Population: 233337059 },
  { Country: 'Papua New Guinea', Population: 228299012 },
  { Country: 'Lao PDR', Population: 227340983 },
  { Country: 'Kyrgyz Republic', Population: 222809200 },
  { Country: 'Paraguay', Population: 221768661 },
  { Country: 'Libya', Population: 217716251 },
  { Country: 'Bosnia and Herzegovina', Population: 215521543 },
  { Country: 'Nicaragua', Population: 213048662 },
  { Country: 'Togo', Population: 204624027 },
  { Country: 'Sierra Leone', Population: 203443826 },
  { Country: 'Ireland', Population: 196019322 },
  { Country: 'Turkmenistan', Population: 189687365 },
  { Country: 'New Zealand', Population: 187593600 },
  { Country: 'Serbia', Population: 186596480 },
  { Country: 'Moldova', Population: 186156257 },
  { Country: 'Lithuania', Population: 182416949 },
  { Country: 'Puerto Rico', Population: 181515497 },
  { Country: 'Jordan', Population: 180850641 },
  { Country: 'Singapore', Population: 173168000 },
  { Country: 'Uruguay', Population: 167612670 },
  { Country: 'Costa Rica', Population: 163515714 },
  { Country: 'Lebanon', Population: 162031498 },
  { Country: 'Eritrea', Population: 161125877 },
  { Country: 'Armenia', Population: 160782905 },
  { Country: 'Central African Republic', Population: 158650217 },
  { Country: 'Albania', Population: 148154320 },
  { Country: 'United Arab Emirates', Population: 134952923 },
  { Country: 'Panama', Population: 130974461 },
  { Country: 'Congo, Rep.', Population: 130701144 },
  { Country: 'Latvia', Population: 130544986 },
  { Country: 'Liberia', Population: 125666085 },
  { Country: 'Jamaica', Population: 124779119 },
  { Country: 'Mauritania', Population: 113489314 },
  { Country: 'Mongolia', Population: 106717826 },
  { Country: 'Slovenia', Population: 104119695 },
  { Country: 'Macedonia, FYR', Population: 104100695 },
  { Country: 'Oman', Population: 93132249 },
  { Country: 'Kosovo', Population: 86627232 },
  { Country: 'Kuwait', Population: 84737006 },
  { Country: 'Lesotho', Population: 81971241 },
  { Country: 'West Bank and Gaza', Population: 77390117 },
  { Country: 'Estonia', Population: 77119567 },
  { Country: 'Namibia', Population: 75238033 },
  { Country: 'Botswana', Population: 70510085 },
  { Country: 'Trinidad and Tobago', Population: 62771502 },
  { Country: 'Guinea-Bissau', Population: 58400669 },
  { Country: 'Mauritius', Population: 56066051 },
  { Country: 'Gabon', Population: 52489952 },
  { Country: 'Gambia, The', Population: 50232086 },
  { Country: 'Cyprus', Population: 43711039 },
  { Country: 'Swaziland', Population: 42858935 },
  { Country: 'Timor-Leste', Population: 41694123 },
  { Country: 'Guyana', Population: 39868752 },
  { Country: 'Fiji', Population: 37505227 },
  { Country: 'Montenegro', Population: 31652512 },
  { Country: 'Qatar', Population: 30075210 },
  { Country: 'Bahrain', Population: 29724096 },
  { Country: 'Djibouti', Population: 26324244 },
  { Country: 'Bhutan', Population: 25987074 },
  { Country: 'Comoros', Population: 22692936 },
  { Country: 'Suriname', Population: 22687861 },
  { Country: 'Equatorial Guinea', Population: 22627794 },
  { Country: 'Luxembourg', Population: 21852156 },
  { Country: 'Malta', Population: 19363458 },
  { Country: 'Cabo Verde', Population: 19178461 },
  { Country: 'Macao SAR, China', Population: 18882494 },
  { Country: 'Solomon Islands', Population: 16859526 },
  { Country: 'Barbados', Population: 14146501 },
  { Country: 'Iceland', Population: 13716537 },
  { Country: 'Bahamas, The', Population: 13446111 },
  { Country: 'Brunei Darussalam', Population: 13322318 },
  { Country: 'Maldives', Population: 11478624 },
  { Country: 'Belize', Population: 10571460 },
  { Country: 'French Polynesia', Population: 9974982 },
  { Country: 'New Caledonia', Population: 9225822 },
  { Country: 'Samoa', Population: 8770470 },
  { Country: 'Vanuatu', Population: 7966814 },
  { Country: 'Curacao', Population: 7898637 },
  { Country: 'Channel Islands', Population: 7515697 },
  { Country: 'St. Lucia', Population: 7336842 },
  { Country: 'Guam', Population: 6647797 },
  { Country: 'Sao Tome and Principe', Population: 6169644 },
  { Country: 'St. Vincent and the Grenadines', Population: 5557117 },
  { Country: 'Grenada', Population: 5366107 },
  { Country: 'Tonga', Population: 5038574 },
  { Country: 'Virgin Islands (U.S.)', Population: 5006756 },
  { Country: 'Micronesia, Fed. Sts.', Population: 4627492 },
  { Country: 'Aruba', Population: 4048374 },
  { Country: 'Antigua and Barbuda', Population: 3887170 },
  { Country: 'Dominica', Population: 3881071 },
  { Country: 'Kiribati', Population: 3874990 },
  { Country: 'Seychelles', Population: 3761184 },
  { Country: 'Isle of Man', Population: 3728525 },
  { Country: 'Bermuda', Population: 3159267 },
  { Country: 'Greenland', Population: 2807533 },
  { Country: 'Andorra', Population: 2704725 },
  { Country: 'St. Kitts and Nevis', Population: 2535482 },
  { Country: 'Faeroe Islands', Population: 2399439 },
  { Country: 'American Samoa', Population: 2294886 },
  { Country: 'Marshall Islands', Population: 2086174 },
  { Country: 'Northern Mariana Islands', Population: 2015842 },
  { Country: 'Monaco', Population: 1595554 },
  { Country: 'Liechtenstein', Population: 1527171 },
  { Country: 'Cayman Islands', Population: 1480956 },
  { Country: 'San Marino', Population: 1298411 },
  { Country: 'St. Martin (French part)', Population: 1020457 },
  { Country: 'Palau', Population: 833299 },
  { Country: 'Turks and Caicos Islands', Population: 775185 },
  { Country: 'Sint Maarten (Dutch part)', Population: 597781 },
  { Country: 'Tuvalu', Population: 466709 },
];

==> apache-superset-4.1.2-source.tar.gz: apache-superset-4.1.2rc1/superset-frontend/packages/superset-ui-demo/storybook/stories/plugins/plugin-chart-echarts/Pie/data.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

export const weekday = [
  { Day: 'Friday', 'SUM(AIR_TIME)': 1943661 },
  { Day: 'Saturday', 'SUM(AIR_TIME)': 1798845 },
  { Day: 'Thursday', 'SUM(AIR_TIME)': 1626157 },
  { Day: 'Sunday', 'SUM(AIR_TIME)': 1048653 },
];

export const population = [
  { Country: 'China', Population: 58345455000 },
  { Country: 'India', Population: 46023037597 },
  { Country: 'United States', Population: 13604468357 },
  { Country: 'Indonesia', Population: 9357861231 },
  { Country: 'Brazil', Population: 7752058955 },
  { Country: 'Russian Federation', Population: 7667188460 },
  { Country: 'Japan', Population: 6454620759 },
  { Country: 'Pakistan', Population: 5696041480 },
  { Country: 'Bangladesh', Population: 5549261462 },
  { Country: 'Nigeria', Population: 5259800493 },
  { Country: 'Mexico', Population: 4444653964 },
  { Country: 'Germany', Population: 4361793335 },
  { Country: 'Vietnam', Population: 3420037000 },
  { Country: 'Philippines', Population: 3272015554 },
  { Country: 'United Kingdom', Population: 3169118137 },
  { Country: 'France', Population: 3151638853 },
  { Country: 'Italy', Population: 3082869665 },
  { Country: 'Egypt, Arab Rep.', Population: 2967887581 },
  { Country: 'Thailand', Population: 2827157965 },
  { Country: 'Turkey', Population: 2805220683 },
  { Country: 'Ethiopia', Population: 2750952916 },
  { Country: 'Iran, Islamic Rep.', Population: 2717528355 },
  { Country: 'Ukraine', Population: 2657782543 },
  { Country: 'Korea, Rep.', Population: 2216456927 },
  { Country: 'Myanmar', Population: 2126848982 },
  { Country: 'Spain', Population: 2115316751 },
  { Country: 'Congo, Dem. Rep.', Population: 2015439254 },
  { Country: 'Poland', Population: 1976772515 },
  { Country: 'South Africa', Population: 1871083248 },
  { Country: 'Colombia', Population: 1776189608 },
  { Country: 'Argentina', Population: 1728332290 },
  { Country: 'Canada', Population: 1470276931 },
  { Country: 'Tanzania', Population: 1413734053 },
  { Country: 'Algeria', Population: 1317290647 },
  { Country: 'Morocco', Population: 1277441301 },
  { Country: 'Kenya', Population: 1253201109 },
  { Country: 'Romania', Population: 1171333228 },
  { Country: 'Peru', Population: 1121937313 },
  { Country: 'Sudan', Population: 1118903636 },
  { Country: 'Uzbekistan', Population: 1053380227 },
  { Country: 'Korea, Dem. Rep.', Population: 1047335229 },
  { Country: 'Venezuela, RB', Population: 1036057583 },
  { Country: 'Nepal', Population: 1007162709 },
  { Country: 'Uganda', Population: 987376102 },
  { Country: 'Iraq', Population: 983604177 },
  { Country: 'Malaysia', Population: 978122682 },
  { Country: 'Australia', Population: 903260509 },
  { Country: 'Afghanistan', Population: 887557752 },
  { Country: 'Sri Lanka', Population: 881137000 },
  { Country: 'Saudi Arabia', Population: 828451525 },
  { Country: 'Mozambique', Population: 807229371 },
  { Country: 'Netherlands', Population: 803013980 },
  { Country: 'Ghana', Population: 801844889 },
  { Country: 'Kazakhstan', Population: 797168043 },
  { Country: 'Chile', Population: 696739897 },
  { Country: 'Yemen, Rep.', Population: 695646128 },
  { Country: 'Cameroon', Population: 664127790 },
  { Country: 'Syrian Arab Republic', Population: 663924524 },
  { Country: 'Madagascar', Population: 656478313 },
  { Country: 'Angola', Population: 641906296 },
  { Country: "Cote d'Ivoire", Population: 634194484 },
  { Country: 'Hungary', Population: 566995908 },
  { Country: 'Czech Republic', Population: 559416359 },
  { Country: 'Belgium', Population: 551921585 },
  { Country: 'Cuba', Population: 550461345 },
  { Country: 'Greece', Population: 547065293 },
  { Country: 'Ecuador', Population: 537148542 },
  { Country: 'Portugal', Population: 536945679 },
  { Country: 'Belarus', Population: 524490000 },
  { Country: 'Cambodia', Population: 523555378 },
  { Country: 'Zimbabwe', Population: 509866860 },
  { Country: 'Burkina Faso', Population: 505122912 },
  { Country: 'Mali', Population: 500758830 },
  { Country: 'Guatemala', Population: 498361800 },
  { Country: 'Niger', Population: 471910464 },
  { Country: 'Malawi', Population: 470725354 },
  { Country: 'Sweden', Population: 468210684 },
  { Country: 'Bulgaria', Population: 456247765 },
  { Country: 'Zambia', Population: 438847085 },
  { Country: 'Austria', Population: 426785647 },
  { Country: 'Tunisia', Population: 415992799 },
  { Country: 'Senegal', Population: 414475224 },
  { Country: 'Haiti', Population: 377521290 },
  { Country: 'Azerbaijan', Population: 374210660 },
  { Country: 'Dominican Republic', Population: 373939753 },
  { Country: 'Switzerland', Population: 369360744 },
  { Country: 'Bolivia', Population: 368308373 },
  { Country: 'Guinea', Population: 362469063 },
  { Country: 'Chad', Population: 355875809 },
  { Country: 'Rwanda', Population: 347121852 },
  { Country: 'Somalia', Population: 332677926 },
  { Country: 'South Sudan', Population: 319024522 },
  { Country: 'Burundi', Population: 305731834 },
  { Country: 'Hong Kong SAR, China', Population: 298353905 },
  { Country: 'Benin', Population: 290736360 },
  { Country: 'Denmark', Population: 283435789 },
  { Country: 'Slovak Republic', Population: 276228375 },
  { Country: 'Finland', Population: 271585488 },
  { Country: 'Tajikistan', Population: 267603756 },
  { Country: 'El Salvador', Population: 266413287 },
  { Country: 'Israel', Population: 263866720 },
  { Country: 'Honduras', Population: 257791863 },
  { Country: 'Croatia', Population: 246197511 },
  { Country: 'Georgia', Population: 241070850 },
  { Country: 'Norway', Population: 233337059 },
  { Country: 'Papua New Guinea', Population: 228299012 },
  { Country: 'Lao PDR', Population: 227340983 },
  { Country: 'Kyrgyz Republic', Population: 222809200 },
  { Country: 'Paraguay', Population: 221768661 },
  { Country: 'Libya', Population: 217716251 },
  { Country: 'Bosnia and Herzegovina', Population: 215521543 },
  { Country: 'Nicaragua', Population: 213048662 },
  { Country: 'Togo', Population: 204624027 },
  { Country: 'Sierra Leone', Population: 203443826 },
  { Country: 'Ireland', Population: 196019322 },
  { Country: 'Turkmenistan', Population: 189687365 },
  { Country: 'New Zealand', Population: 187593600 },
  { Country: 'Serbia', Population: 186596480 },
  { Country: 'Moldova', Population: 186156257 },
  { Country: 'Lithuania', Population: 182416949 },
  { Country: 'Puerto Rico', Population: 181515497 },
  { Country: 'Jordan', Population: 180850641 },
  { Country: 'Singapore', Population: 173168000 },
  { Country: 'Uruguay', Population: 167612670 },
  { Country: 'Costa Rica', Population: 163515714 },
  { Country: 'Lebanon', Population: 162031498 },
  { Country: 'Eritrea', Population: 161125877 },
  { Country: 'Armenia', Population: 160782905 },
  { Country: 'Central African Republic', Population: 158650217 },
  { Country: 'Albania', Population: 148154320 },
  { Country: 'United Arab Emirates', Population: 134952923 },
  { Country: 'Panama', Population: 130974461 },
  { Country: 'Congo, Rep.', Population: 130701144 },
  { Country: 'Latvia', Population: 130544986 },
  { Country: 'Liberia', Population: 125666085 },
  { Country: 'Jamaica', Population: 124779119 },
  { Country: 'Mauritania', Population: 113489314 },
  { Country: 'Mongolia', Population: 106717826 },
  { Country: 'Slovenia', Population: 104119695 },
  { Country: 'Macedonia, FYR', Population: 104100695 },
  { Country: 'Oman', Population: 93132249 },
  { Country: 'Kosovo', Population: 86627232 },
  { Country: 'Kuwait', Population: 84737006 },
  { Country: 'Lesotho', Population: 81971241 },
  { Country: 'West Bank and Gaza', Population: 77390117 },
  { Country: 'Estonia', Population: 77119567 },
  { Country: 'Namibia', Population: 75238033 },
  { Country: 'Botswana', Population: 70510085 },
  { Country: 'Trinidad and Tobago', Population: 62771502 },
  { Country: 'Guinea-Bissau', Population: 58400669 },
  { Country: 'Mauritius', Population: 56066051 },
  { Country: 'Gabon', Population: 52489952 },
  { Country: 'Gambia, The', Population: 50232086 },
  { Country: 'Cyprus', Population: 43711039 },
  { Country: 'Swaziland', Population: 42858935 },
  { Country: 'Timor-Leste', Population: 41694123 },
  { Country: 'Guyana', Population: 39868752 },
  { Country: 'Fiji', Population: 37505227 },
  { Country: 'Montenegro', Population: 31652512 },
  { Country: 'Qatar', Population: 30075210 },
  { Country: 'Bahrain', Population: 29724096 },
  { Country: 'Djibouti', Population: 26324244 },
  { Country: 'Bhutan', Population: 25987074 },
  { Country: 'Comoros', Population: 22692936 },
  { Country: 'Suriname', Population: 22687861 },
  { Country: 'Equatorial Guinea', Population: 22627794 },
  { Country: 'Luxembourg', Population: 21852156 },
  { Country: 'Malta', Population: 19363458 },
  { Country: 'Cabo Verde', Population: 19178461 },
  { Country: 'Macao SAR, China', Population: 18882494 },
  { Country: 'Solomon Islands', Population: 16859526 },
  { Country: 'Barbados', Population: 14146501 },
  { Country: 'Iceland', Population: 13716537 },
  { Country: 'Bahamas, The', Population: 13446111 },
  { Country: 'Brunei Darussalam', Population: 13322318 },
  { Country: 'Maldives', Population: 11478624 },
  { Country: 'Belize', Population: 10571460 },
  { Country: 'French Polynesia', Population: 9974982 },
  { Country: 'New Caledonia', Population: 9225822 },
  { Country: 'Samoa', Population: 8770470 },
  { Country: 'Vanuatu', Population: 7966814 },
  { Country: 'Curacao', Population: 7898637 },
  { Country: 'Channel Islands', Population: 7515697 },
  { Country: 'St. Lucia', Population: 7336842 },
  { Country: 'Guam', Population: 6647797 },
  { Country: 'Sao Tome and Principe', Population: 6169644 },
  { Country: 'St. Vincent and the Grenadines', Population: 5557117 },
  { Country: 'Grenada', Population: 5366107 },
  { Country: 'Tonga', Population: 5038574 },
  { Country: 'Virgin Islands (U.S.)', Population: 5006756 },
  { Country: 'Micronesia, Fed. Sts.', Population: 4627492 },
  { Country: 'Aruba', Population: 4048374 },
  { Country: 'Antigua and Barbuda', Population: 3887170 },
  { Country: 'Dominica', Population: 3881071 },
  { Country: 'Kiribati', Population: 3874990 },
  { Country: 'Seychelles', Population: 3761184 },
  { Country: 'Isle of Man', Population: 3728525 },
  { Country: 'Bermuda', Population: 3159267 },
  { Country: 'Greenland', Population: 2807533 },
  { Country: 'Andorra', Population: 2704725 },
  { Country: 'St. Kitts and Nevis', Population: 2535482 },
  { Country: 'Faeroe Islands', Population: 2399439 },
  { Country: 'American Samoa', Population: 2294886 },
  { Country: 'Marshall Islands', Population: 2086174 },
  { Country: 'Northern Mariana Islands', Population: 2015842 },
  { Country: 'Monaco', Population: 1595554 },
  { Country: 'Liechtenstein', Population: 1527171 },
  { Country: 'Cayman Islands', Population: 1480956 },
  { Country: 'San Marino', Population: 1298411 },
  { Country: 'St. Martin (French part)', Population: 1020457 },
  { Country: 'Palau', Population: 833299 },
  { Country: 'Turks and Caicos Islands', Population: 775185 },
  { Country: 'Sint Maarten (Dutch part)', Population: 597781 },
  { Country: 'Tuvalu', Population: 466709 },
];

export const sales = [
  { Product: 'Laptop', 'SUM(AMOUNT)': 30 },
  { Product: 'Workstation', 'SUM(AMOUNT)': 28 },
  { Product: 'Phone', 'SUM(AMOUNT)': 26 },
  { Product: 'Tablet', 'SUM(AMOUNT)': 24 },
  { Product: 'PDA', 'SUM(AMOUNT)': 22 },
  { Product: 'Ink Pad', 'SUM(AMOUNT)': 20 },
  { Product: 'Accessories', 'SUM(AMOUNT)': 18 },
  { Product: 'Pad', 'SUM(AMOUNT)': 16 },
];
